<!-- markdownlint-disable-file MD024 -->

# fed-rag API Changelog

All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/),
and this project adheres to [Semantic Versioning](https://semver.org/).

## Unreleased

- ...

## [0.1.0] - 2025-05-16

### Added

- `RAGSystem` and `fed_rag.types.rag`
